@@ -1,82 +1,33 @@
 import re
 from functools import wraps
-from typing import Callable, List, Optional, overload
+from typing import Callable, List, Optional
 
 from typing_extensions import Concatenate, ParamSpec
 
-from ..corpora.corpus_types import Word, Sentence, Text
+from ..corpora.corpus_types import Word, Sentence, Text, WS
 
-__all__ = [
-    "autopsy_sentence",
-    "autopsy_text",
-    "split_sentence",
-    "split_text",
-    "join_words",
-    "join_sentences",
-    "extract_first_sentence",
-    "extract_nth_sentence",
-    "remove_first_sentence",
-    "remove_nth_sentence",
-    "wrap_text_with_sentences",
-]
-
-P = ParamSpec("P")
-
-
-@overload
-def strip(strings: List[Word]) -> List[Word]:
-    ...
-
-
-@overload
-def strip(strings: List[Sentence]) -> List[Sentence]:
-    ...
-
-
-def strip(strings):
-    """Removes leading and trailing whitespaces from each string in the list."""
-    return [s.strip() for s in strings]
-
-
-@overload
-def remove_empty_strings(strings: List[Word]) -> List[Word]:
-    ...
-
-
-@overload
-def remove_empty_strings(strings: List[Sentence]) -> List[Sentence]:
-    ...
-
-
-def remove_empty_strings(strings):
-    """Removes empty strings from the list of strings."""
-    return [s for s in strings if s]
+_P = ParamSpec("_P")
 
 
 def autopsy_sentence(
-    func: Callable[Concatenate[List[Word], P], List[Word]]
-) -> Callable[Concatenate[Sentence, P], Sentence]:
-    """The decorator follows this procedure:
+    func: Callable[Concatenate[List[Word], _P], List[Word]]
+) -> Callable[Concatenate[Sentence, _P], Sentence]:
+    """The decorator follows these steps:
         1. Splits the input sentence into words.
         2. Applies the `func` to the words.
-        3. joins the words returned by 'func' into a sentence.
+        3. Joins the words returned by `func` into a sentence.
 
     Args:
-        func (Callable[Concatenate[List[Word], P], List[Word]]):
-            The function to be decorated. It should take a list of words as its first argument.
+        func (Callable[Concatenate[List[Word], _P], List[Word]]):
+            The function to be decorated.
 
     Returns:
-        Callable[Concatenate[Sentence, P], Sentence]:
-            A decorated function that performs the procedure.
+        Callable[Concatenate[Sentence, _P], Sentence]:
+            A wrapper function that performs the steps.
 
-    Example:
-        >>> from typing import List, TypeVar
-        ...
-        >>> Word = TypeVar("Word", bound=str)
-        ...
-        ...
+    Examples:
         >>> @autopsy_sentence
-        ... def remove_second_word(words: List[Word]) -> List[Word]:
+        ... def remove_second_word(words):
         ...    try:
         ...        del words[1]
         ...        return words
@@ -88,38 +39,33 @@ def autopsy_sentence(
         "짜장면을 먹었다"
     """
     @wraps(func)
-    def wrapped(sentence: Sentence, *args: P.args, **kwargs: P.kwargs) -> Sentence:
+    def wrapped(sentence: Sentence, *args: _P.args, **kwargs: _P.kwargs) -> Sentence:
         words = split_sentence(sentence)
-        words = func(words, *args, **kwargs)
-        sentence = join_words(words)
-        return sentence
+        processed_words = func(words, *args, **kwargs)
+        processed_sentence = join_words(processed_words)
+        return processed_sentence
     return wrapped
 
 
 def autopsy_text(
-    func: Callable[Concatenate[List[Sentence], P], List[Sentence]]
-) -> Callable[Concatenate[Text, P], Text]:
-    """The decorator follows this procedure:
+    func: Callable[Concatenate[List[Sentence], _P], List[Sentence]]
+) -> Callable[Concatenate[Text, _P], Text]:
+    """The decorator follows these steps:
         1. Splits the input text into sentences.
         2. Applies the `func` to the sentences.
-        3. joins the sentences returned by 'func' into a text.
+        3. Joins the sentences returned by `func` into a text.
 
     Args:
-        func (Callable[Concatenate[List[Sentence], P], List[Sentence]]):
-            The function to be decorated. It should take a list of sentences as its first argument.
+        func (Callable[Concatenate[List[Sentence], _P], List[Sentence]]):
+            The function to be decorated.
 
     Returns:
-        Callable[Concatenate[Text, P], Text]:
-            A decorated function that performs the procedure.
+        Callable[Concatenate[Text, _P], Text]:
+            A wrapper function that performs the steps.
 
-    Example:
-        >>> from typing import List, TypeVar
-        ...
-        >>> Sentence = TypeVar("Sentence", bound=str)
-        ...
-        ...
+    Examples:
         >>> @autopsy_text
-        ... def remove_second_sentence(sentences: List[Sentence]) -> List[Sentence]:
+        ... def remove_second_sentence(sentences):
         ...    try:
         ...        del sentences[1]
         ...        return sentences
@@ -131,11 +77,11 @@ def autopsy_text(
         "짜장면을 맛있게 먹었다."
     """
     @wraps(func)
-    def wrapped(text: Text, *args: P.args, **kwargs: P.kwargs) -> Text:
+    def wrapped(text: Text, *args: _P.args, **kwargs: _P.kwargs) -> Text:
         sentences = split_text(text)
-        sentences = func(sentences, *args, **kwargs)
-        text = join_sentences(sentences)
-        return text
+        processed_sentences = func(sentences, *args, **kwargs)
+        processed_text = join_sentences(processed_sentences)
+        return processed_text
     return wrapped
 
 
@@ -149,7 +95,7 @@ def split_sentence(sentence: Sentence) -> List[Word]:
 
 def split_text(text: Text) -> List[Sentence]:
     """Splits the text into sentences."""
-    sentences = re.split(r"[.?!]", text)
+    sentences = re.split(r"[.]", text)
     sentences = strip(sentences)
     sentences = remove_empty_strings(sentences)
     return sentences
@@ -169,6 +115,16 @@ def join_sentences(sentences: List[Sentence]) -> Text:
     return text
 
 
+def strip(strings: List[WS]) -> List[WS]:
+    """Removes leading and trailing whitespaces from each string in the list."""
+    return [s.strip() for s in strings]
+
+
+def remove_empty_strings(strings: List[WS]) -> List[WS]:
+    """Removes empty strings from the list of strings."""
+    return [s for s in strings if s]
+
+
 def extract_first_sentence(text: Text) -> Sentence:
     """Extracts the first sentence from the text."""
     return extract_nth_sentence(text, 0)
@@ -178,7 +134,8 @@ def extract_nth_sentence(text: Text, n: int) -> Sentence:
     """Extracts the nth sentence from the text."""
     sentences = split_text(text)
     try:
-        return sentences[n]
+        nth_sentence = sentences[n]
+        return nth_sentence
     except IndexError:
         return ""
 
@@ -188,27 +145,32 @@ def remove_first_sentence(text: Text) -> Text:
     return remove_nth_sentence(text, 0)
 
 
-@autopsy_text
-def remove_nth_sentence(sentences: List[Sentence], n: int) -> List[Sentence]:
-    """Removes the nth sentence from the list of sentences. Decorated with `autopsy_text`.
-
-    Args:
-        sentences (List[Sentence]): The list of sentences.
-        n (int): The index of the sentence to extract.
-
-    Returns:
-        List[Sentence]: The modified list of sentences with the nth sentence removed.
-
-    Example:
-        >>> text = "짜장면을 맛있게 먹었다. 짬뽕도 맛있게 먹었다."
-        >>> remove_nth_sentence(text, 1)
-        "짜장면을 맛있게 먹었다"
-    """
+def remove_nth_sentence(text: Text, n: int) -> Text:
+    """Removes the nth sentence from the text"""
+    sentences = split_text(text)
     try:
         del sentences[n]
-        return sentences
+        text_without_nth_sentence = join_sentences(sentences)
+        return text_without_nth_sentence
     except IndexError:
-        return sentences
+        return text
+
+
+def pass_empty_text(func: Callable[Concatenate[Text, _P], Text]) -> Callable[Concatenate[Text, _P], Text]:
+    """Returns the input text directly if it is empty, otherwise calls the decorated function.
+
+    Args:
+        func(Callable[Concatenate[Text, _P], Text]): The function to be decorated.
+
+    Returns:
+        A wrapper function.
+    """
+    @wraps(func)
+    def wrapped(text: Text, *args: _P.args, **kwargs: _P.kwargs) -> Text:
+        if not text:
+            return text
+        return func(text, *args, **kwargs)
+    return wrapped
 
 
 def wrap_text_with_sentences(
@@ -217,10 +179,10 @@ def wrap_text_with_sentences(
     prefix_sentences: Optional[List[Sentence]] = None,
     suffix_sentences: Optional[List[Sentence]] = None
 ) -> Text:
-    """Wraps the input text with the specified prefix and suffix sentences.
+    """Wraps the text with the specified prefix and suffix sentences.
 
     Args:
-        text (Text): The text to wrap with sentences.
+        text (Text): The input text to wrap with sentences.
         prefix_sentences (List[Sentence]): List of sentences to add at the beginning of the text.
         suffix_sentences (List[Sentence]): List of sentences to add at the end of the text.
 
